Function parse_rustc_version

pub fn parse_rustc_version(
    version: impl AsRef<str>,
) -> Result<(String, RustChannel), String>
Parses the output of rustc --version.

Errors

Returns an error if it fails to execute rustc, the process exits with non-zero status, or it fails to parse the output.

Panics

Panics if the process writes non-UTF bytes to stdout.